<?php

/**
 * Core Theme Functions.
 * @author  	 DeoThemes
 * @copyright  (c) Copyright by DeoThemes
 * @link       https://deothemes.com
 * @package 	 Everse
 * @since 		 1.0.0
 */
if ( !defined( 'ABSPATH' ) ) {
    exit( 'Direct script access denied.' );
}
/**
 * Checks if WooCommerce is activated
 * @return boolean
 */
if ( !function_exists( 'everse_is_woocommerce_activated' ) ) {
    function everse_is_woocommerce_activated()
    {
        return ( class_exists( 'WooCommerce' ) ? true : false );
    }

}
/**
 * Checks if LearnDash post
 * @return boolean
 */
if ( !function_exists( 'everse_is_learndash_post' ) ) {
    function everse_is_learndash_post()
    {
        if ( !class_exists( 'SFWD_LMS' ) ) {
            return;
        }
        if ( is_singular( 'sfwd-courses' ) || is_singular( 'sfwd-lessons' ) || is_singular( 'sfwd-topic' ) || is_singular( 'sfwd-quiz' ) || is_singular( 'sfwd-certificates' ) || is_singular( 'sfwd-assignment' ) ) {
            return true;
        }
        return false;
    }

}
/**
 * Shim for wp_body_open
 *
 * @since  1.0.0
 */
if ( !function_exists( 'wp_body_open' ) ) {
    function wp_body_open()
    {
        do_action( 'wp_body_open' );
    }

}
/**
 * Fix skip link focus in IE11.
 *
 * This does not enqueue the script because it is tiny and because it is only for IE11,
 * thus it does not warrant having an entire dedicated blocking script being loaded.
 *
 * @link https://git.io/vWdr2
 */
function everse_skip_link_focus_fix()
{
    // The following is minified via `terser --compress --mangle -- assets/js/skip-link-focus-fix.js`.
    ?>
	<script>
	/(trident|msie)/i.test(navigator.userAgent)&&document.getElementById&&window.addEventListener&&window.addEventListener("hashchange",function(){var t,e=location.hash.substring(1);/^[A-z0-9_-]+$/.test(e)&&(t=document.getElementById(e))&&(/^(?:a|select|input|button|textarea)$/i.test(t.tagName)||(t.tabIndex=-1),t.focus())},!1);
	</script>
	<?php 
}

add_action( 'wp_print_footer_scripts', 'everse_skip_link_focus_fix' );
/**
 * Check if page built with Elementor
 *
 * @since  1.0.0
 */
function everse_is_elementor_page()
{
    $elementor_page = get_post_meta( get_the_ID(), '_elementor_edit_mode', true );
    if ( is_search() || is_archive() ) {
        return false;
    }
    
    if ( (bool) $elementor_page ) {
        return true;
    } else {
        return false;
    }

}

/**
* Gutenberg Check
*
* @since 1.0.0
*/
function everse_is_gutenberg()
{
    return function_exists( 'register_block_type' );
}

/**
 * Check if it's CPT archive
 *
 * @since  1.0.0
 */
function everse_is_cpt( $cpt )
{
    return is_tax( "{$cpt}_categories" ) || is_post_type_archive( $cpt );
}

/**
 * Get the array of active CPT extensions
 * 
 * @since 1.7
 * @return array $extensions array of active cpt
 */
function everse_get_active_cpt()
{
    $extensions = get_option( 'everse_extensions_settings', [
        'projects' => '1',
        'services' => '1',
    ] );
    return $extensions;
}

/**
 * Allow shorcodes in text widgets
 */
add_filter( 'widget_text', 'do_shortcode' );
/**
 * Custom excerpt length
 */
function everse_custom_excerpt_length( $length )
{
    if ( is_admin() ) {
        return;
    }
    $excerpt_length = get_theme_mod( 'everse_settings_posts_excerpt_settings', 55 );
    return $excerpt_length;
}

add_filter( 'excerpt_length', 'everse_custom_excerpt_length' );
if ( !function_exists( 'everse_sidebar' ) ) {
    /**
     * Get sidebar
     *
     * @since 1.0.0
     */
    function everse_sidebar( $sidebar = '' )
    {
        ?>
			<aside class="sidebar col-lg">
				<div itemtype="https://schema.org/WPSideBar" itemscope="itemscope" id="secondary" class="widget-area" role="complementary">
					<?php 
        everse_sidebar_before();
        ?>
					<?php 
        dynamic_sidebar( $sidebar );
        ?>
					<?php 
        everse_sidebar_after();
        ?>
				</div> <!-- #secondary -->
			</aside>
		<?php 
    }

}
if ( !function_exists( 'everse_is_active_sidebar' ) ) {
    /**
     * Check if sidebar is active
     *
     * @since 1.0.0
     */
    function everse_is_active_sidebar( $sidebar = '', $layout = '', $default = 'right-sidebar' )
    {
        if ( 'fullwidth' !== everse_layout_type( $layout, $default ) && is_active_sidebar( 'everse-' . $sidebar . '-sidebar' ) ) {
            return true;
        }
    }

}
if ( !function_exists( 'everse_layout_type' ) ) {
    /**
     * Check layout type based on customizer and meta settings
     * @return string $type Layout type
     */
    function everse_layout_type( $type, $default = 'right-sidebar' )
    {
        $layout = '';
        $meta = get_post_meta( get_the_ID(), '_everse_' . $type . '_layout', true );
        $page_for_posts = get_option( 'page_for_posts' );
        if ( is_home() && $page_for_posts ) {
            $meta = get_post_meta( $page_for_posts, '_everse_page_layout', true );
        }
        if ( is_archive() || is_404() || is_search() || is_home() ) {
            $meta = '';
        }
        if ( 'left-sidebar' == get_theme_mod( 'everse_settings_' . $type . '_layout_type', $default ) ) {
            $layout = ( $meta ? $meta : 'left-sidebar' );
        }
        if ( 'right-sidebar' == get_theme_mod( 'everse_settings_' . $type . '_layout_type', $default ) ) {
            $layout = ( $meta ? $meta : 'right-sidebar' );
        }
        if ( 'fullwidth' == get_theme_mod( 'everse_settings_' . $type . '_layout_type', $default ) ) {
            $layout = ( $meta ? $meta : 'fullwidth' );
        }
        return $layout;
    }

}
/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function everse_body_classes( $classes )
{
    // Adds a class of group-blog to blogs with more than 1 published author.
    if ( is_multi_author() ) {
        $classes[] = 'everse-group-blog';
    }
    // Page Layout Class
    if ( is_page() ) {
        
        if ( everse_is_woocommerce_activated() ) {
            
            if ( is_front_page() ) {
                $classes[] = '';
            } elseif ( is_cart() || is_checkout() || is_account_page() ) {
                $classes[] = 'everse-' . everse_layout_type( 'shop_pages', 'fullwidth' );
            } else {
                
                if ( everse_is_active_sidebar( 'page', 'page' ) ) {
                    $classes[] = 'everse-' . everse_layout_type( 'page' );
                } else {
                    $classes[] = 'everse-no-sidebar';
                }
            
            }
        
        } else {
            
            if ( is_active_sidebar( 'everse-page-sidebar' ) ) {
                $classes[] = 'everse-' . everse_layout_type( 'page' );
            } else {
                $classes[] = 'everse-no-sidebar';
            }
        
        }
    
    }
    // Blog Layout Class
    if ( is_home() ) {
        
        if ( everse_is_learndash_post() ) {
            $classes[] = '';
        } else {
            $classes[] = 'everse-' . everse_layout_type( 'blog' );
        }
    
    }
    // Single Post Layout Class
    if ( is_single() && 'post' == get_post_type() ) {
        
        if ( is_active_sidebar( 'everse-blog-sidebar' ) ) {
            $classes[] = 'everse-' . everse_layout_type( 'single_post' );
        } else {
            $classes[] = 'everse-no-sidebar';
        }
    
    }
    // Archives Layout Class
    if ( is_archive() ) {
        
        if ( everse_is_woocommerce_activated() && is_shop() ) {
            $classes[] = '';
        } else {
            $classes[] = 'everse-' . everse_layout_type( 'archive', 'fullwidth' );
        }
    
    }
    // Search Layout Class
    if ( is_search() ) {
        $classes[] = 'everse-' . everse_layout_type( 'search_results', 'fullwidth' );
    }
    // Shop Layout Class
    if ( everse_is_woocommerce_activated() ) {
        if ( !is_product() && is_woocommerce() || is_shop() ) {
            $classes[] = 'everse-' . everse_layout_type( 'shop', 'fullwidth' );
        }
    }
    $classes[] = '';
    return $classes;
}

add_filter( 'body_class', 'everse_body_classes' );
/**
 * Adds custom admin classes.
 *
 * @param string $classes Classes for the body element.
 * @return string
 */
function everse_admin_body_classes( $classes )
{
    $screen = get_current_screen();
    // Add blog layout class
    
    if ( $screen->id === "post" ) {
        $classes = 'everse-' . everse_layout_type( 'single_post' );
        if ( !is_active_sidebar( 'everse-blog-sidebar' ) ) {
            $classes = 'everse-no-sidebar';
        }
    }
    
    // Add page layout class
    
    if ( $screen->id === "page" ) {
        $classes = 'everse-' . everse_layout_type( 'page' );
        if ( !is_active_sidebar( 'everse-page-sidebar' ) ) {
            $classes = 'everse-no-sidebar';
        }
    }
    
    return $classes;
}

add_filter( 'admin_body_class', 'everse_admin_body_classes' );