<?php
/**
 * The template for displaying all pages.
 * @author  	 DeoThemes
 * @copyright  (c) Copyright by DeoThemes
 * @link       https://deothemes.com
 * @package 	 Everse
 * @since 		 1.4.1
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! class_exists( 'Everse_Theme_Update' ) ) {

	/**
	 * Everse_Theme_Update initial setup
	 *
	 * @since 1.4.1
	 */
	class Everse_Theme_Update {

		/**
		 * Class instance.
		 *
		 * @access private
		 * @var $instance Class instance.
		 */
		private static $instance;

		/**
		 * Initiator
		 */
		public static function get_instance() {
			if ( ! isset( self::$instance ) ) {
				self::$instance = new self();
			}
			return self::$instance;
		}

		/**
		 *  Constructor
		 */
		public function __construct() {
			if ( is_admin() ) {				
				add_action( 'admin_init', __CLASS__ . '::init', 5 );		
			} else {
				add_action( 'wp', __CLASS__ . '::init', 5 );			
			}
		}

		/**
		 * Implement theme update logic.
		 *
		 * @since 1.4.1
		 */
		public static function init() {

			// Get auto saved version number.
			$saved_version = get_option( 'everse_theme_version', false );

			// If equals then return.
			if ( version_compare( $saved_version, EVERSE_VERSION, '=' ) ) {
				return;
			}

			// If updated to 1.2 update headings font setting from H1 customizer setting
			if ( version_compare( $saved_version, '1.2', '<' ) ) {
				self::v_1_2();
			}

			// If updated to 1.4.1 update logo width and height customizer setting
			if ( version_compare( $saved_version, '1.4.1', '<' ) ) {
				self::v_1_4_1();
			}

			// Update auto saved version number.
			update_option( 'everse_theme_version', EVERSE_VERSION );

		}


		/**
		* Updates headings font setting from H1 customizer setting.
		* 
		* @since 1.2
		*/
		public static function v_1_2() {	
			$theme_options = get_option( 'everse_settings' );

			if ( ! isset( $theme_options['headings_swap_with_h1_font_setting'] ) ) {
				$h1_setting = get_theme_mod( 'everse_settings_headings_h1' );
				$headings_setting = get_theme_mod( 'everse_settings_headings_font' );

				if ( $h1_setting ) {
					$headings_new_setting = array(
						'font-family' 	 => $h1_setting['font-family'],
						'font-weight' 	 => absint($h1_setting['font-weight']),
						'line-height' 	 => $h1_setting['line-height'],
						'letter-spacing' => $h1_setting['letter-spacing'],
						'text-transform' => $h1_setting['text-transform'],
						'variant'				 => $h1_setting['variant']
					);

					set_theme_mod( 'everse_settings_headings_font', $headings_new_setting );

					$theme_options['headings_swap_with_h1_font_setting'] = true;
					update_option( 'headings_swap_with_h1_font_setting', $theme_options );
				}

			}
		}


		/**
		 * Update options of older version than 1.4.1.
		 *
		 * @since 1.4.1
		 */
		public static function v_1_4_1() {
			$theme_options = get_option( 'everse_settings' );

			// Set the logo width based on the previous height settings
			if ( ! isset( $theme_options['logo_width_based_on_height'] ) ) {
				$logo_id = attachment_url_to_postid( get_theme_mod( 'everse_settings_logo_dark' ) );	

				$height = get_theme_mod( 'everse_settings_header_logo_height' );

				if ( ! $height ) {
					return;
				}
				
				$height_setting = wp_get_attachment_image_src( $logo_id, [ 0, $height ] );
				$width = $height_setting[1];

				set_theme_mod( 'everse_settings_header_logo_width', $width );
				set_theme_mod( 'everse_settings_header_logo_sticky_width', $width );
				
				remove_theme_mod( 'everse_settings_header_logo_height' );
				remove_theme_mod( 'everse_settings_header_logo_sticky_height' );

				$theme_options['logo_width_based_on_height'] = true;
				update_option( 'everse_settings', $theme_options );
			}
		}
		
	}
}

/**
 * Kicking this off by calling 'get_instance()' method
 */
Everse_Theme_Update::get_instance();