<?php
/**
 * The template for displaying CPT content on archive pages.
 * @author  	 DeoThemes
 * @copyright  (c) Copyright by DeoThemes
 * @link       https://deothemes.com
 * @package 	 Everse
 * @since 		 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Direct script access denied.' );
}

$columns = get_theme_mod( "everse_settings_project_columns", 'col-lg-4' );
$custom_URL = ( ! empty( get_post_meta( get_the_ID(), "_everse_{$everse_cpt[1]}_custom_url", true ) ) ) ? get_post_meta( get_the_ID(), "_everse_{$everse_cpt[1]}_custom_url", true ) : get_the_permalink();
$image_size = ( 'col-lg-12' == $columns ) ? 'everse_featured_large' : 'everse_featured_medium';
?>


<article id="post-<?php the_ID(); ?>" <?php post_class( 'cpt__entry' ); ?> itemscope="itemscope" itemtype="https://schema.org/Article">

	<?php if ( has_post_thumbnail() ) : ?>
		<figure class="entry__img-holder">
			<a href="<?php echo esc_url( $custom_URL ); ?>" title="<?php the_title_attribute(); ?>">
				<?php the_post_thumbnail( esc_html( $image_size ), array( 'class' => 'entry__img cpt__img' ) ); ?>
			</a>
		</figure>						
	<?php endif; ?>

	<div class="cpt__body">

		<div class="entry__categories cpt__categories">
			<?php $terms = get_the_terms( get_the_ID(), "{$everse_cpt[0]}_categories" );
			if ( ! empty( $terms ) && ! is_wp_error( $terms ) ) {
				foreach ( $terms as $term ) {
					echo '<a href="' . esc_url( get_category_link( $term->term_id ) ) . '" class="cpt__category entry-category">' . esc_html( $term->name ) . '</a>';
				}
			} ?>
		</div>
		
		<?php the_title( sprintf( '<h3 class="entry__title cpt__title"><a href="%s">',
			esc_url( $custom_URL ) ),
			'</a></h3>'
		); ?>		

		<a href="<?php echo esc_url( $custom_URL ); ?>" class="read-more entry__read-more">
			<span class="cpt__read-more-text"><?php echo apply_filters( 'everse_cpt_read_more_text', esc_html__( 'Read More', 'everse' ) ); ?></span>
		</a>

	</div> <!-- .cpt__body -->

</article>